@@ -42,7 +42,7 @@ my(%class_callbacks) =
 
 my($myself);
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 # --------------------------------------------------
 
@@ -2561,15 +2561,11 @@ L<CGI::Snapp> - A almost back-compat fork of CGI::Application
 
 L<CGI::Snapp::Dispatch> and L<CGI::Snapp::Dispatch::Regexp> - Dispatch requests to CGI::Snapp-based objects
 
-L<CGI::Snapp::Plugin::Forward> - A plugin for CGI::Snapp to switch cleanly to another run mode within the same app
-
-L<CGI::Snapp::Plugin::Redirect> - A plugin for CGI::Snapp to simplify using HTTP redirects
-
 L<CGI::Snapp::Demo::One> - A template-free demo of CGI::Snapp using just 1 run mode
 
 L<CGI::Snapp::Demo::Two> - A template-free demo of CGI::Snapp using N run modes
 
-L<CGI::Snapp::Demo::Three> - A template-free demo of CGI::Snapp using CGI::Snapp::Plugin::Forward
+L<CGI::Snapp::Demo::Three> - A template-free demo of CGI::Snapp using the forward() method
 
 L<CGI::Snapp::Demo::Four> - A template-free demo of CGI::Snapp using Log::Handler::Plugin::DBI
 
